import java.awt.*;
import java.awt.geom.*;

/**
 * A circle that can be manipulated and drawn.
 * @author Joel Ross
 * @author adapted from Michael Kolling and David J. Barnes
 * @version Jan 2013
 *
 */
public class Circle extends DrawableShape
{
	//instance variables
    private int x;
    private int y;
    private int radius;
	private String color;
    private boolean filled;

    /**
     * Creates a new Circle object with default location, radius, and color.
     */
    public Circle()
    {
    	//give instance variables default values
    	this.x = 30;
    	this.y = 40;
    	this.radius = 20;
    	this.color = "blue";
    	this.filled = true;

    	//this(30, 40, 20, "blue"); //equivalent line
    }
    
    /**
     * Creates a new Circle object with the given x position, y position, radius, and color.
     * @param x The circle's x position
     * @param y The circle's y position
     * @param radius The circle's radius
     * @param color The circle's color. Can either be: "red", "green", "blue", "cyan", "magenta", "yellow", "pink", "gray", "black", "white"
     */
    private Circle(int x, int y, int radius, String color)
    {
    	//give instance variables values passed in
    	this.x = x;
    	this.y = y;
    	this.radius = radius;
    	this.color = color;
    	this.filled = true;
    }

    /**
     * Returns the circle's current x position
     */
    public int getXPosition()
    {
    	return x;
    }

	/**
	 * Sets the circle's x position to the given value
	 */
	private void setXPosition(int x)
	{
		this.x = x;
	}

	/**
	 * Returns the circle's current y position
	 */
	public int getYPosition()
	{
		return y;
	}

	/**
	 * Sets the circle's y position to the given value
	 */
	private void setYPosition(int y)
	{
		this.y = y;
	}

	/**
	 * Returns the circle's current radius
	 */
	public int getRadius()
	{
		return radius;
	}

	/**
	 * Sets the circle's radius to the given value
	 */
	public void setRadius(int radius)
	{
		this.radius = radius;
	}

	/**
	 * Returns the circle's current color (as a String). Can either be: 
	 * "red", "green", "blue", "cyan", "magenta", "yellow", "pink", "gray", "black", "white"
	 */
	public String getColor()
	{
		return color;
	}

	/**
	 * Set the circle's color to the given value. Can either be:
	 * "red", "green", "blue", "cyan", "magenta", "yellow", "pink", "gray", "black", "white"
	 */
	public void setColor(String color)
	{
		this.color = color;
	}

	/**
	 * Returns whether the circle is filled or not
	 */
	public boolean isFilled()
	{
		return filled;
	}

	/**
	 * Sets whether the circle should be filled; can either be true or false
	 */
	public void setFilled(boolean filled)
	{
		this.filled = filled;
	}

	/**
	 * Move the circle horizontally the specified number of pixels.
	 */
	public void moveHorizontal(int distance)
	{
		x += distance;
	}

	/**
	 * Move the circle vertically the specified number of pixels.
	 */
	public void moveVertical(int distance)
	{
		y += distance;
	}
	
    /**
     * Move the circle a few pixels to the right.
     */
    public void moveRight()
    {
        moveHorizontal(20);
    }

    /**
     * Move the circle a few pixels to the left.
     */
    public void moveLeft()
    {
        moveHorizontal(-20);
    }

    /**
     * Move the circle a few pixels up.
     */
    public void moveUp()
    {
        moveVertical(-20);
    }

    /**
     * Move the circle a few pixels down.
     */
    public void moveDown()
    {
        moveVertical(20);
    }

	/* (non-Javadoc)
	 * @see DrawableShape#draw(java.awt.Graphics2D)
	 */
	public void draw(Graphics2D g2d)
    {
		g2d.setColor(getColorFromString(color));
		if(filled)
			g2d.fillOval(x,y,radius,radius);
		else
			g2d.drawOval(x,y,radius,radius);
    }
}
