import java.awt.*;
import java.awt.geom.*;

/**
 * A rectangle that can be manipulated and drawn.
 * @author Joel Ross
 * @author adapted from Michael Kolling and David J. Barnes
 * @version Jan 2013
 *
 */
public class Rectangle extends DrawableShape
{
	//instance variables
    private int x;
    private int y;
    private int width;
    private int height;
	private String color;
    private boolean filled;

    /**
     * Creates a new Rectangle object with default location, radius, and color.
     */
    public Rectangle()
    {
    	//give instance variables default values
    	this.x = 60;
    	this.y = 50;
    	this.width = 40;
    	this.height = 30;
    	this.color = "red";
    	this.filled = true;

    	//this(60, 50, 40, 20, "red"); //equivalent line
    }
    
    /**
     * Creates a new Rectangle object with the given position, size, and color.
     * @param x The rectangle's x position
     * @param y The rectangle's y position
     * @param width The rectangle's width
     * @param height The rectangle's height
     * @param color The rectangle's color. Can either be: "red", "green", "blue", "cyan", "magenta", "yellow", "pink", "gray", "black", "white"
     */
    private Rectangle(int x, int y, int width, int height, String color)
    {
    	//give instance variables values passed in
    	this.x = x;
    	this.y = y;
    	this.width = width;
    	this.height = height;
    	this.color = color;
    	this.filled = true;
    }

    /**
     * Returns the rectangle's current x position
     */
    public int getXPosition()
    {
    	return x;
    }

	/**
	 * Sets the rectangle's x position to the given value
	 */
	private void setXPosition(int x)
	{
		this.x = x;
	}

	/**
	 * Returns the rectangle's current y position
	 */
	public int getYPosition()
	{
		return y;
	}

	/**
	 * Sets the rectangle's y position to the given value
	 */
	private void setYPosition(int y)
	{
		this.y = y;
	}

	/**
	 * Returns the rectangle's current width
	 */
	public int getWidth()
	{
		return width;
	}

	/**
	 * Sets the rectangle's width to the given value
	 */
	public void setWidth(int width)
	{
		this.width = width;
	}

	/**
	 * Returns the rectangle's current height
	 */
	public int getHeight()
	{
		return height;
	}

	/**
	 * Sets the rectangle's height to the given value
	 */
	public void setHeight(int height)
	{
		this.height = height;
	}
	
	/**
	 * Returns the rectangle's current color (as a String). Can either be: 
	 * "red", "green", "blue", "cyan", "magenta", "yellow", "pink", "gray", "black", "white"
	 */
	public String getColor()
	{
		return color;
	}

	/**
	 * Set the circle's color to the given value. Can either be:
	 * "red", "green", "blue", "cyan", "magenta", "yellow", "pink", "gray", "black", "white"
	 */
	public void setColor(String color)
	{
		this.color = color;
	}

	
	/**
	 *Returns whether the rectangle is filled or not
	 */
	public boolean isFilled()
	{
		return filled;
	}

	/**
	 * Sets whether the rectangle should be filled; can either be true or false
	 */
	public void setFilled(boolean filled)
	{
		this.filled = filled;
	}

	/**
	 * Move the rectangle horizontally the specified number of pixels
	 */
	public void moveHorizontal(int distance)
	{
		x += distance;
	}

	/**
	 * Move the rectangle vertically the specified number of pixels
	 */
	public void moveVertical(int distance)
	{
		y += distance;
	}
	
    /**
     * Move the rectangle a few pixels to the right.
     */
    public void moveRight()
    {
        moveHorizontal(20);
    }

    /**
     * Move the rectangle a few pixels to the left.
     */
    public void moveLeft()
    {
        moveHorizontal(-20);
    }

    /**
     * Move the rectangle a few pixels up.
     */
    public void moveUp()
    {
        moveVertical(-20);
    }

    /**
     * Move the rectangle a few pixels down.
     */
    public void moveDown()
    {
        moveVertical(20);
    }

	/* (non-Javadoc)
	 * @see DrawableShape#draw(java.awt.Graphics2D)
	 */
	public void draw(Graphics2D g2d)
    {
		g2d.setColor(getColorFromString(color));
		if(filled)
			g2d.fillRect(x,y,width,height);
		else
			g2d.fillRect(x,y,width,height);
    }
}
