import java.awt.*;
import java.awt.geom.*;

/**
 * An equilateral triangle that can be manipulated and drawn.
 * @author Joel Ross
 * @author adapted from Michael Kolling and David J. Barnes
 * @version Jan 2013
 *
 */
public class Triangle extends DrawableShape
{
    //instance variables
    private int x;
    private int y;
    private int sideLength;
    private double rotation;
    private String color;
    private boolean filled;

    /**
     * Creates a new Triangle object with default location, radius, and color.
     */
    public Triangle()
    {
        //give instance variables default values
        this.x = 40;
        this.y = 50;
        this.sideLength = 30;
        this.rotation = 0.0;
        this.color = "green";
        this.filled = true;

        //this(40, 50, 30, "green"); //equivalent line
    }
    
    /**
     * Creates a new Triangle object with the given position, side length, and color.
     * @param x The triangle's x position
     * @param y The triangle's y position
     * @param sideLength The triangle's side length
     * @param color The triangle's color. Can either be: "red", "green", "blue", "cyan", "magenta", "yellow", "pink", "gray", "black", "white"
     */
    private Triangle(int x, int y, int sideLength, String color)
    {
        //give instance variables values passed in
        this.x = x;
        this.y = y;
        this.sideLength = sideLength;
        this.rotation = 0.0;
        this.color = color;
        this.filled = true;
    }

    /**
     * Returns the triangle's current x position
     */
    public int getXPosition()
    {
        return x;
    }

    /**
	 * Sets the triangle's x position to the given value
     */
    private void setXPosition(int x)
    {
        this.x = x;
    }

    /**
     * Returns the triangle's current y position
     */
    public int getYPosition()
    {
        return y;
    }

    /**
	 * Sets the triangle's x position to the given value
     */
    private void setYPosition(int y)
    {
        this.y = y;
    }

    /**
     * Returns the triangle's current side length
     */
    public int getSideLength()
    {
        return sideLength;
    }

    /**
	 * Sets the triangles's side length to the given value
     */
    public void setSideLength(int sideLength)
    {
        this.sideLength = sideLength;
    }

    /**
     * Returns the triangle's current rotation (in radians)
     */
    public double getRotation()
    {
        return rotation;
    }

    /**
     * Set the triangle's current rotation (in radians). Note that this number should have a decimal value.
     */
    public void setRotation(double rotation)
    {
        this.rotation = rotation;
    }
    
    /**
	 * Returns the triangle's current color (as a String). Can either be: 
     * "red", "green", "blue", "cyan", "magenta", "yellow", "pink", "gray", "black", "white"
     */
    public String getColor()
    {
        return color;
    }

    /**
	 * Set the circle's color to the given value. Can either be:
     * "red", "green", "blue", "cyan", "magenta", "yellow", "pink", "gray", "black", "white"
     */
    public void setColor(String color)
    {
        this.color = color;
    }

    
    /**
     * Returns whether the triangle is filled or not
     */
    public boolean isFilled()
    {
        return filled;
    }

    /**
     * Sets whether the triangle is filled; can either be true or false
     */
    public void setFilled(boolean filled)
    {
        this.filled = filled;
    }

    /**
     * Move the triangle horizontally by the specified number of pixels.
     */
    public void moveHorizontal(int distance)
    {
        x += distance;
    }

    /**
     * Move the triangle horizontally by the specified number of pixels.
     */
    public void moveVertical(int distance)
    {
        y += distance;
    }
    
    /**
     * Move the triangle a few pixels to the right.
     */
    public void moveRight()
    {
        moveHorizontal(20);
    }

    /**
     * Move the triangle a few pixels to the left.
     */
    public void moveLeft()
    {
        moveHorizontal(-20);
    }

    /**
     * Move the triangle a few pixels up.
     */
    public void moveUp()
    {
        moveVertical(-20);
    }

    /**
     * Move the triangle a few pixels down.
     */
    public void moveDown()
    {
        moveVertical(20);
    }

    /* (non-Javadoc)
     * @see DrawableShape#draw(java.awt.Graphics2D)
     */
    public void draw(Graphics2D g2d)
    {
        g2d.setColor(getColorFromString(color));

        double height = Math.sqrt(3)/2.0*sideLength; //the height of the triangle
        int[] xPoints = {x, x+sideLength/2, x+sideLength}; //get the coordinates of the corners of the triangle
        int[] yPoints = {(int)(y+height), y, (int)(y+height)};
        
        g2d.rotate(rotation, x+sideLength/2, y+sideLength/2); //rotate the context around the center
        
        if(filled)
            g2d.fill(new Polygon(xPoints, yPoints, 3));
        else
            g2d.draw(new Polygon(xPoints, yPoints, 3));
        
        g2d.rotate(-rotation, x+sideLength/2, y+sideLength/2); //unrotate the context (again around the center)
    
    }
}
